run_workflow

Function run_workflow 

pub async fn run_workflow<E: NodeExecutor + ?Sized>(
    workflow: &WorkflowDefinition,
    execution: &ExecutionMetadata,
    executor: &E,
) -> Result<()>
Execute the workflow by invoking the provided executor for each node.

Errors

Returns an error if the default run policy rejects the workflow shape or any node execution fails.