run_workflow_with_observers

Function run_workflow_with_observers 

pub async fn run_workflow_with_observers<E, H, M>(
    workflow: &WorkflowDefinition,
    execution: &ExecutionMetadata,
    executor: &E,
    lifecycle_hook: &H,
    metadata_sink: Arc<M>,
) -> Result<()>
where E: NodeExecutor + ?Sized, H: LifecycleHook + ?Sized, M: MetadataSink + 'static,
Execute the workflow through one executor and report observer records.

Errors

Returns an error if the default run policy rejects the workflow shape, observation fails, metadata collection fails, or node execution fails.