run_workflow_with_policy

Function run_workflow_with_policy 

pub async fn run_workflow_with_policy<E: NodeExecutor + ?Sized>(
    workflow: &WorkflowDefinition,
    execution: &ExecutionMetadata,
    executor: &E,
    policy: WorkflowRunPolicy,
) -> Result<()>
Execute the workflow through one executor with an explicit run policy.

Errors

Returns an error if the run policy rejects the workflow shape or any node execution fails.