run_workflow_with_registry

Function run_workflow_with_registry 

pub async fn run_workflow_with_registry<R>(
    workflow: &WorkflowDefinition,
    execution: &ExecutionMetadata,
    registry: &R,
) -> Result<()>
Execute the workflow by resolving one executor for each node from a registry.

Errors

Returns an error if the default run policy rejects the workflow shape, executor resolution fails, or any node execution fails.