pub struct DeadlockWatchdogPolicy { /* private fields */ }Expand description
Configuration for no-progress deadlock detection.
Implementations
Sourceimpl DeadlockWatchdogPolicy
impl DeadlockWatchdogPolicy
Sourcepub const fn new(no_progress_timeout: Duration) -> Self
pub const fn new(no_progress_timeout: Duration) -> Self
Create a no-progress watchdog policy.
A zero duration is allowed and fires on the next watchdog poll, which is useful for deterministic tests.
Sourcepub const fn no_progress_timeout(&self) -> Duration
pub const fn no_progress_timeout(&self) -> Duration
Maximum interval allowed without any node reaching a terminal state.