SingleNodeExecutorRegistry

Struct SingleNodeExecutorRegistry 

pub struct SingleNodeExecutorRegistry<'a, E: ?Sized> { /* private fields */ }
Registry adapter that runs every workflow node through the same executor.

Implementations

Source

impl<'a, E: ?Sized> SingleNodeExecutorRegistry<'a, E>

pub const fn new(executor: &'a E) -> Self

Create a registry that resolves every node to executor.