pub struct WorkflowOutputContracts { /* private fields */ }Expand description
Output-port contract subset used by the workflow runner.
Implementations
Sourceimpl WorkflowOutputContracts
impl WorkflowOutputContracts
Sourcepub fn from_node_contracts(
workflow: &WorkflowDefinition,
contracts: &[NodeContract],
) -> Result<Self>
pub fn from_node_contracts( workflow: &WorkflowDefinition, contracts: &[NodeContract], ) -> Result<Self>
Build output validation contracts for a workflow.
Errors
Returns an error when any workflow output port lacks a matching output contract or a contract references an unknown workflow output.